-module(element_tel).
%%-author('Vladimir Galunshchikov').

-include_lib("nitro/include/nitro.hrl").
-include_lib("nitro/include/event.hrl").

-export([
  render_element/1
]).


render_element(Record) when Record#tel.show_if == false -> [<<>>];

render_element(Record) ->
  Id = case Record#tel.postback of
    [] -> Record#tel.id;
    Postback ->
      ID0 = case Record#tel.id of
        [] -> nitro:temp_id();
        I -> I
      end,
      nitro:wire( #event{type = click, postback = Postback, target = ID0,
                         source = Record#tel.source, delegate = Record#tel.delegate} ),
      ID0
  end,
  List = [
    %% global
    {<<"accesskey">>, Record#tel.accesskey},
    {<<"class">>, Record#tel.class},
    {<<"contenteditable">>,
       case Record#tel.contenteditable of
         true -> "true";
         false -> "false";
         _ -> []
       end},
    
    {<<"contextmenu">>, Record#tel.contextmenu},
    {<<"dir">>,
       case Record#tel.dir of
         ltr -> "ltr";
         rtl -> "rtl";
         auto -> "auto";
         _ -> []
       end},
    
    {<<"draggable">>,
       case Record#tel.draggable of
         true -> "true";
         false -> "false";
         _ -> []
       end},
    
    {<<"dropzone">>, Record#tel.dropzone},
    {<<"hidden">>,
       case Record#tel.hidden of
         "hidden" -> "hidden";
         _ -> []
       end},
    
    {<<"id">>, Id},
    {<<"lang">>, Record#tel.lang},
    {<<"spellcheck">>,
       case Record#tel.spellcheck of
         true -> "true";
         false -> "false";
         _ -> []
       end},
    
    {<<"style">>, Record#tel.style},
    {<<"tabindex">>, Record#tel.tabindex},
    {<<"title">>, Record#tel.title},
    {<<"translate">>,
       case Record#tel.contenteditable of
         "yes" -> "yes";
         "no" -> "no";
         _ -> []
       end},
    
    %% spec
    {<<"autocomplete">>,
       case Record#tel.autocomplete of
         true -> "on";
         false -> "off";
         _ -> []
       end},
    
    {<<"autofocus">>,
       case Record#tel.autofocus of
         true -> "autofocus";
         _ -> []
       end},
    
    {<<"disabled">>,
       case Record#tel.disabled of
         true -> "disabled";
         _ -> []
       end},
    
    {<<"form">>, Record#tel.form},
    {<<"list">>, Record#tel.list},
    {<<"maxlength">>, Record#tel.maxlength},
    {<<"name">>, Record#tel.name},
    {<<"pattern">>, Record#tel.pattern},
    {<<"placeholder">>, Record#tel.placeholder},
    {<<"readonly">>,
       case Record#tel.readonly of
         true -> "readonly";
         _ -> []
       end},
    
    {<<"required">>,
       case Record#tel.required of
         true -> "required";
         _ -> []
       end},
    
    {<<"size">>, Record#tel.size},
    {<<"type">>, <<"tel">>},
    {<<"value">>, Record#tel.value} | Record#tel.data_fields
  ],
  
  wf_tags:emit_tag(<<"input">>, nitro:render(Record#tel.body), List).

